@@ -1,6 +1,7 @@
 import platform
 
 import click
+from rich import traceback
 
 from task import task_add
 from task import task_describe
@@ -9,10 +10,13 @@ from task import task_list
 from task import task_rm
 from task import utils
 
+
 __version__ = "0.1.0"
 
+traceback.install()
 
-@click.group(invoke_without_command=True)
+
+@click.group(invoke_without_command=True, cls=utils.AliasedGroup)
 @click.pass_context
 @click.option("-v", "--version", is_flag=True, help="print version")
 @click.option("-d", "--debug", is_flag=True, help="debug mode")
