@@ -1,14 +1,14 @@
 import click
-from click_default_group import DefaultGroup
 
+from task import database
 from task import utils
 
 
 @click.group(
     name='done',
-    cls=DefaultGroup,
+    cls=utils.AliasedGroup,
     default='task-done',
-    default_if_no_args=True
+    default_if_no_args=True,
 )
 def main():
     """Finished task."""
@@ -20,11 +20,11 @@ def task_done(task_id: int = 0) -> int:
     """Task is done."""
     if utils.does_db_exist()[0] is False:
         # TODO better prints than this
-        print("Database not found")
-        print("See doc")
+        utils.error("Database not found")
         return 1
 
-    # 0 should be the latest task that can be set to done
-    new_done = utils.set_task_done(task_id)
-    utils.update_task(task_id)
-    print(f"Done {new_done}")
+    db = database.sql_init()
+    table = database.setup_todo_table(db)
+
+    database.set_task_done(db, table, task_id)
+    utils.info(f"Done {task_id}")
